@@ -2,18 +2,19 @@ package cmdconfig
 
 import (
 	"fmt"
-	pfilepaths "github.com/turbot/pipe-fittings/filepaths"
 	"log"
 	"os"
 
+	pfilepaths "github.com/turbot/pipe-fittings/v2/filepaths"
+
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 	filehelpers "github.com/turbot/go-kit/files"
 	"github.com/turbot/go-kit/types"
-	pconstants "github.com/turbot/pipe-fittings/constants"
-	"github.com/turbot/pipe-fittings/parse"
-	"github.com/turbot/pipe-fittings/workspace_profile"
-	"github.com/turbot/steampipe/pkg/constants"
+	pconstants "github.com/turbot/pipe-fittings/v2/constants"
+	"github.com/turbot/pipe-fittings/v2/parse"
+	"github.com/turbot/pipe-fittings/v2/workspace_profile"
+	"github.com/turbot/steampipe/v2/pkg/constants"
 )
 
 // Viper fetches the global viper instance
@@ -110,6 +111,9 @@ func setBaseDefaults() error {
 		// memory
 		pconstants.ArgMemoryMaxMbPlugin: 1024,
 		pconstants.ArgMemoryMaxMb:       1024,
+
+		// plugin start timeout
+		pconstants.ArgPluginStartTimeout: constants.PluginStartTimeout.Seconds(),
 	}
 
 	for k, v := range defaults {
