@@ -5,8 +5,8 @@ import (
 
 	"github.com/jackc/pgx/v5/pgconn"
 	"github.com/jackc/pgx/v5/pgxpool"
-	pqueryresult "github.com/turbot/pipe-fittings/queryresult"
-	"github.com/turbot/steampipe/pkg/query/queryresult"
+	pqueryresult "github.com/turbot/pipe-fittings/v2/queryresult"
+	"github.com/turbot/steampipe/v2/pkg/query/queryresult"
 )
 
 type Client interface {
