@@ -5,7 +5,7 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/turbot/pipe-fittings/utils"
+	"github.com/turbot/pipe-fittings/v2/utils"
 	"golang.org/x/exp/maps"
 )
 
