@@ -1,6 +1,6 @@
 package plugin
 
-import "github.com/turbot/pipe-fittings/hclhelpers"
+import "github.com/turbot/pipe-fittings/v2/hclhelpers"
 
 type PluginConnection interface {
 	GetDeclRange() hclhelpers.Range
