@@ -5,17 +5,20 @@ import (
 	"io"
 	"log"
 	"os/exec"
+	"path/filepath"
 	"syscall"
+	"time"
 
 	"github.com/hashicorp/go-hclog"
 	"github.com/hashicorp/go-plugin"
-	"github.com/turbot/pipe-fittings/app_specific"
-	"github.com/turbot/pipe-fittings/constants"
+	"github.com/spf13/viper"
+	"github.com/turbot/pipe-fittings/v2/app_specific"
+	"github.com/turbot/pipe-fittings/v2/constants"
 	"github.com/turbot/steampipe-plugin-sdk/v5/logging"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
-	"github.com/turbot/steampipe/pkg/pluginmanager_service/grpc"
-	pb "github.com/turbot/steampipe/pkg/pluginmanager_service/grpc/proto"
-	pluginshared "github.com/turbot/steampipe/pkg/pluginmanager_service/grpc/shared"
+	"github.com/turbot/steampipe/v2/pkg/pluginmanager_service/grpc"
+	pb "github.com/turbot/steampipe/v2/pkg/pluginmanager_service/grpc/proto"
+	pluginshared "github.com/turbot/steampipe/v2/pkg/pluginmanager_service/grpc/shared"
 )
 
 // StartNewInstance loads the plugin manager state, stops any previous instance and instantiates a new plugin manager
@@ -43,9 +46,20 @@ func StartNewInstance(steampipeExecutablePath string) (*State, error) {
 // when the plugin mananager is first started by steampipe, we derive the exe path from the running process and
 // store it in the plugin manager state file - then if the fdw needs to start the plugin manager it knows how to
 func start(steampipeExecutablePath string) (*State, error) {
+	// first resolve the steampipe executable path to be the actual exe path
+	// - so that we DO NOT store a symlink in the plugin manager state
+	// (If steampipe is started via a symlink, if we do not resolve the symlink, the state file will contain the symlink
+	// which means pluginmanager.State.verifyRunning will return a false negative, i.e. it will think the plugin
+	// manager is not running, as the exe stored in the state file does not match the actual running process)
+	resolvedExecutablePath, err := filepath.EvalSymlinks(steampipeExecutablePath)
+	if err != nil {
+		log.Printf("[WARN] could not resolve symlink for %s: %s", steampipeExecutablePath, err)
+		return nil, err
+	}
+
 	// note: we assume the install dir has been assigned to file_paths.app_specific.InstallDir
 	// - this is done both by the FDW and Steampipe
-	pluginManagerCmd := exec.Command(steampipeExecutablePath,
+	pluginManagerCmd := exec.Command(resolvedExecutablePath,
 		"plugin-manager",
 		"--"+constants.ArgInstallDir, app_specific.InstallDir)
 	// set attributes on the command to ensure the process is not shutdown when its parent terminates
@@ -64,6 +78,7 @@ func start(steampipeExecutablePath string) (*State, error) {
 		Cmd:              pluginManagerCmd,
 		AllowedProtocols: []plugin.Protocol{plugin.ProtocolGRPC},
 		Logger:           logger,
+		StartTimeout:     time.Duration(viper.GetInt(constants.ArgPluginStartTimeout)) * time.Second,
 	})
 
 	if _, err := client.Start(); err != nil {
@@ -74,7 +89,7 @@ func start(steampipeExecutablePath string) (*State, error) {
 	}
 
 	// create a plugin manager state.
-	state := NewState(steampipeExecutablePath, client.ReattachConfig())
+	state := NewState(resolvedExecutablePath, client.ReattachConfig())
 
 	log.Printf("[TRACE] start: started plugin manager, pid %d", state.Pid)
 
@@ -124,7 +139,7 @@ func stop(state *State) error {
 	pluginManager.rawClient.Kill()
 	log.Printf("[TRACE] pluginManager.Shutdown killed raw client")
 
-	// now kill the plugin manager
+	// now kill the plugin manager process itself if needed and clear the state file
 	return state.kill()
 }
 
